@@ -384,6 +384,24 @@ class ASTListener(ModelicaListener):
             operands=[self.ast[e] for e in ctx.expr()]
         )
 
+    def exitExpr_not(self, ctx: ModelicaParser.Expr_notContext):
+        self.ast[ctx] = ast.Expression(
+            operator='not',
+            operands=[self.ast[ctx.expr()]]
+        )
+
+    def exitExpr_and(self, ctx: ModelicaParser.Expr_andContext):
+        self.ast[ctx] = ast.Expression(
+            operator='and',
+            operands=[self.ast[e] for e in ctx.expr()]
+        )
+
+    def exitExpr_or(self, ctx: ModelicaParser.Expr_orContext):
+        self.ast[ctx] = ast.Expression(
+            operator='or',
+            operands=[self.ast[e] for e in ctx.expr()]
+        )
+
     def exitExpr_neg(self, ctx: ModelicaParser.Expr_negContext):
         self.ast[ctx] = ast.Expression(
             operator=ctx.op.text,
@@ -408,7 +426,13 @@ class ASTListener(ModelicaListener):
     # PRIMARY ===========================================================
 
     def exitPrimary_unsigned_number(self, ctx: ModelicaParser.Primary_unsigned_numberContext):
-        self.ast[ctx] = ast.Primary(value=float(ctx.getText()))
+        number_string = ctx.getText()
+        try:
+            val = int(number_string)
+        except ValueError:
+            val = float(number_string)
+
+        self.ast[ctx] = ast.Primary(value=val)
 
     def exitPrimary_string(self, ctx: ModelicaParser.Primary_stringContext):
         val = ctx.getText()
@@ -449,7 +473,7 @@ class ASTListener(ModelicaListener):
         )
 
     def exitType_specifier(self, ctx: ModelicaParser.Type_specifierContext):
-        for element in reversed([self.ast[ctx] for ctx in ctx.type_specifier_element()]):
+        for element in reversed([self.ast[x] for x in ctx.type_specifier_element()]):
             if ctx in self.ast:
                 element.child = [self.ast[ctx]]
             self.ast[ctx] = element
@@ -466,7 +490,7 @@ class ASTListener(ModelicaListener):
         )
 
     def exitComponent_reference(self, ctx: ModelicaParser.Component_referenceContext):
-        for element in reversed([self.ast[ctx] for ctx in ctx.component_reference_element()]):
+        for element in reversed([self.ast[x] for x in ctx.component_reference_element()]):
             if ctx in self.ast:
                 element.child = [self.ast[ctx]]
             self.ast[ctx] = element
